@@ -7,7 +7,7 @@ from math import sqrt, prod
 from ..http import check
 
 class capy:
-  __version__ = "1.1.0"
+  __version__ = "1.2.0"
   #Functions
   __doc__ = f"Capylang v{__version__}. Please check README.md for documentation. Docstrings are not easy to make." # Python int Docstring
   
@@ -32,6 +32,10 @@ class capy:
   def add(*args):
     return sum(args)
 
+  @staticmethod
+  def log(*args,**kwargs):
+    print(*args,**kwargs)
+
   @staticmethod
   def minus(*args):
     return reduce(sub, args)
